summaryrefslogtreecommitdiff
path: root/src/xine-engine/configfile.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/xine-engine/configfile.h')
-rw-r--r--src/xine-engine/configfile.h19
1 files changed, 18 insertions, 1 deletions
diff --git a/src/xine-engine/configfile.h b/src/xine-engine/configfile.h
index 859214d1c..e98138fa3 100644
--- a/src/xine-engine/configfile.h
+++ b/src/xine-engine/configfile.h
@@ -50,6 +50,7 @@ extern "C" {
typedef struct cfg_entry_s cfg_entry_t;
typedef struct config_values_s config_values_t;
+
struct cfg_entry_s {
cfg_entry_t *next;
config_values_t *config;
@@ -175,7 +176,7 @@ struct config_values_s {
cfg_entry_t* (*lookup_entry) (config_values_t *self, const char *key);
/*
* unregister callback function
*/
void (*unregister_callback) (config_values_t *self, const char *key);
@@ -185,11 +186,27 @@ struct config_values_s {
void (*dispose) (config_values_t *self);
/*
+ * callback called when a new config entry is registered
+ */
+ void (*set_new_entry_callback) (config_values_t *self, xine_config_cb_t new_entry_cb, void *cb_data);
+
+ /*
+ * unregister the callback
+ */
+ void (*unset_new_entry_callback) (config_values_t *self);
+
+ /*
* config values are stored here:
*/
cfg_entry_t *first, *last, *cur;
/*
+ * new entry callback
+ */
+ xine_config_cb_t new_entry_cb;
+ void *new_entry_cbdata;
+
+ /*
* mutex for modification to the config
*/
pthread_mutex_t config_lock;
@@ -175,7 +176,7 @@ struct config_values_s {
cfg_entry_t* (*lookup_entry) (config_values_t *self, const char *key);
/*
- * unregister callback function
+ * unregister entry callback function
*/
void (*unregister_callback) (config_values_t *self, const char *key);